._app_1rrvr_1{display:flex;flex-flow:column nowrap;grid-template-rows:auto 1fr;height:100vh;overflow:hidden}._main_1rrvr_9{display:flex;flex-flow:row nowrap;flex-grow:1;overflow:hidden}._header_1rrvr_16{font-size:1.2em;display:flex;flex-flow:row nowrap;align-items:center;justify-content:space-between;background:black;color:#fff;padding:1em}._header_1rrvr_16 a{color:#fff}._sidebar_1rrvr_30{width:37.5%;height:100%;grid-area:sidebar;border-right:1px solid black;overflow-y:auto}._sidebar_1rrvr_30 li{border-bottom:1px solid gray}._details_1rrvr_41{width:62.5%;overflow:hidden;height:100%}._noRequest_1rrvr_47,._noRequestSelected_1rrvr_47{width:100%;height:100%;display:flex;justify-content:center;align-items:center}._details_1xvog_1{height:100%;display:flex;flex-flow:column nowrap;align-items:stretch;overflow:hidden}._header_1xvog_9{flex-shrink:0;flex-grow:0}._content_1xvog_14{flex-grow:1;flex-shrink:1;overflow-y:auto}._summary_1xvog_20{font-size:2em}._tabs_1xvog_24{display:flex;border-bottom:1px solid black}._tabs_1xvog_24:last-child{flex-grow:1}._tab_1xvog_24{background-color:#fff;border:none;border-top:1px solid black;border-right:1px solid black;border-radius:0;color:#000;font-size:1.2em;padding:.5em}._tab_1xvog_24._selected_1xvog_42{background-color:#000;color:#fff}._emptySpace_1xvog_47{flex-grow:1;display:flex;justify-content:flex-end;align-items:center;font-size:1.2em;padding:.5em}._resend_1xvog_56{margin-left:1em}._headers_1xvog_60{display:grid;grid-template-columns:auto 1fr;border:1px solid black;margin:1em;overflow-x:auto}._headers_1xvog_60 h2{grid-column:1/span 2;background-color:#000;color:#fff;padding:.5em}._headers_1xvog_60>div{line-break:auto;padding:.5em}._headers_1xvog_60>div:nth-of-type(4n),._headers_1xvog_60>div:nth-of-type(4n - 1){background-color:#d3d3d3}._requestSummary_11fqk_1{display:grid;grid-template-columns:auto 1fr auto;padding:1em;grid-gap:1em;align-items:center}._statusCode_11fqk_9{padding:.2em;border-radius:.4em;background-color:#a9a9a9}._statusCode_11fqk_9._info_11fqk_14,._statusCode_11fqk_9._success_11fqk_14,._statusCode_11fqk_9._redirect_11fqk_14{background-color:#228b22}._statusCode_11fqk_9._clientError_11fqk_17,._statusCode_11fqk_9._serverError_11fqk_17{background-color:red}._content_13eis_1{width:100%;height:100%;display:flex;flex-flow:column nowrap;overflow:hidden}._header_13eis_9{flex-shrink:0;flex-grow:0;width:100%;display:flex;padding:.5em;background-color:#000;color:#fff}._body_13eis_19{flex-grow:1;flex-shrink:1;overflow-y:auto}._body_13eis_19 pre{width:100%;height:100%;padding:1em;font-family:monospace;overflow:auto}._body_13eis_19 iframe{height:100%;width:100%}._renderError_13eis_36{width:100%;height:100%;display:flex;flex-flow:column nowrap;justify-content:center;align-items:center}._renderError_13eis_36 a{margin-top:1em;text-decoration:underline;color:#00f}html,body,div,span,applet,object,iframe,h1,h2,h3,h4,h5,h6,p,blockquote,pre,a,abbr,acronym,address,big,cite,code,del,dfn,em,img,ins,kbd,q,s,samp,small,strike,strong,sub,sup,tt,var,b,u,i,center,dl,dt,dd,ol,ul,li,fieldset,form,label,legend,table,caption,tbody,tfoot,thead,tr,th,td,article,aside,canvas,details,embed,figure,figcaption,footer,header,hgroup,menu,nav,output,ruby,section,summary,time,mark,audio,video{margin:0;padding:0;border:0;font-size:100%;font:inherit;vertical-align:baseline}article,aside,details,figcaption,figure,footer,header,hgroup,menu,nav,section{display:block}body{line-height:1}ol,ul{list-style:none}blockquote,q{quotes:none}blockquote:before,blockquote:after,q:before,q:after{content:"";content:none}table{border-collapse:collapse;border-spacing:0}*{box-sizing:border-box}html,body,#root{margin:0;padding:0;height:100vh;width:100vw;font-family:sans-serif;overflow:hidden}
